@@ -207,6 +207,8 @@ def resolveMRs(item):
                     # this means the requested version is a tag rather
                     # (not a branch)
                     pass
+        else:  # disabled project case, just clean up pointless checkout opts
+            item.checkout = ("ignore", {})
     else:
         return [resolveMRs(p) for p in item]
     return item
