@@ -282,8 +282,9 @@ def create_mr_slots(sources, platforms, merge, model_slots):
 
     logger.info('Creating Ref Slot')
     logger.info('name: {}'.format(model_name + '-ref'))
+    # always create ref_slot for all platforms to maximise reuse
     ref_slot = clone_slot(model_slot, model_name + '-ref', 'MR reference slot',
-                          platforms)
+                          None)
     ref_repos = slot_repos(model_slot, with_disabled=True)
     # If some sources are not in the slot definition, add them
     for name, ss in project_sources.items():
