@@ -153,6 +153,32 @@ def test_Project():
     assert cb.kwargs == {'special': False}, cb.kwargs
 
 
+def test_Package():
+    'Configuration.Package'
+    Package = Configuration.Package
+
+    mockCheckout = MockFunc()
+    p = Package('Gen/DecFiles', 'Sim10', checkout=mockCheckout)
+    assert p.name == 'Gen/DecFiles'
+    assert p.version == 'Sim10'
+    assert p._checkout == mockCheckout
+
+    cb = MockFunc()
+    p = Package('Gen/DecFiles', 'Sim10', checkout=cb)
+    p.checkout()
+    assert cb.args == (p, ), cb.args
+    assert cb.kwargs == {}, cb.kwargs
+    assert hasattr(p, 'checkout_log')
+    assert p.checkout_log
+
+    # test setting checkout_opts via checkout descriptor
+    cb = MockFunc()
+    p = Package('Gen/DecFiles', 'Sim10', checkout=(cb, {'special': False}))
+    p.checkout()
+    assert cb.args == (p, ), cb.args
+    assert cb.kwargs == {'special': False}, cb.kwargs
+
+
 def test_Slot():
     'Configuration.Slot'
     Slot = Configuration.Slot
