@@ -24,7 +24,7 @@ with open(os.path.join(_testdata, 'ci-test-hook-content.json')) as f:
 def test_get_hook_args():
     args = GitlabMR.get_hook_args(_hook_content)
     assert args.sources == ['lhcb/Rec!1753']
-    assert not args.merge
+    assert args.merge
 
 
 def test_gitlab_feedback():
@@ -40,6 +40,7 @@ def test_gitlab_feedback():
 def test_main():
     GitlabMR.get_main_job_config([
         'gaudi/Gaudi!123', 'lhcb/LHCb@v50r6', 'lhcb-datapkg/TCK/HltTCK!5',
+        '--branch',
         '--platforms=x86_64-centos7-gcc8-opt,x86_64-centos7-gcc8-dbg'
     ])
     try:
@@ -95,28 +96,29 @@ def test_main_with_hook():
     hook_var = 'TEST_MAIN_WITH_HOOK'
     args = ['--hook-var=' + hook_var]
 
-    os.environ[hook_var] = json.dumps(_hook_content)
+    content = deepcopy(_hook_content)
+    content["object_attributes"]["note"] += ' --branch'
+    os.environ[hook_var] = json.dumps(content)
     config = GitlabMR.get_main_job_config(args)[0]
     assert config['sources'] == ['lhcb/Rec!1753']
     assert not config['merge']
 
-    content = deepcopy(_hook_content)
-
     # support full URLs to Gitlab
     content["object_attributes"]["note"] = (
-        '/ci-test https://gitlab.cern.ch/lhcb/LHCb/-/merge_requests/111')
+        '/ci-test --branch https://gitlab.cern.ch/lhcb/LHCb/-/merge_requests/111'
+    )
     os.environ[hook_var] = json.dumps(content)
     config = GitlabMR.get_main_job_config(args)[0]
     assert 'lhcb/LHCb!111' in config['sources']
 
     # deduce group when not specified
-    content["object_attributes"]["note"] = '/ci-test LHCb!111'
+    content["object_attributes"]["note"] = '/ci-test --branch LHCb!111'
     os.environ[hook_var] = json.dumps(content)
     config = GitlabMR.get_main_job_config(args)[0]
     assert 'lhcb/LHCb!111' in config['sources']
 
     # deduce group/project when not specified
-    content["object_attributes"]["note"] = '/ci-test !111'
+    content["object_attributes"]["note"] = '/ci-test --branch !111'
     os.environ[hook_var] = json.dumps(content)
     try:
         config = GitlabMR.get_main_job_config(args)[0]
@@ -137,6 +139,17 @@ def test_main_with_hook():
         assert 'lhcb/Rec!1753' in message and 'lhcb/Rec!111' in message
         assert 'is already merged' in message
 
+    # again without --merge as that should be default
+    content["object_attributes"]["note"] = '/ci-test !111'
+    os.environ[hook_var] = json.dumps(content)
+    try:
+        config = GitlabMR.get_main_job_config(args)[0]
+        assert False
+    except GitlabMR.TriggerError as e:
+        message = str(e)
+        assert 'lhcb/Rec!1753' in message and 'lhcb/Rec!111' in message
+        assert 'is already merged' in message
+
     # throw an exception when parser fails
     content["object_attributes"]["note"] = '/ci-test --garbage'
     os.environ[hook_var] = json.dumps(content)
