@@ -702,6 +702,10 @@ ${extraRequires}
             # Classic vXr* for data packages
             # In that case we depend on the Provides with the major version number included
             reqstr = "Requires: %s_v%s" % (tarBallName, major)
+        elif patch == '*':
+            # Classic vXrYp* for data packages
+            # In that case we depend on the Provides with the major and minor version numbers included
+            reqstr = "Requires: %s_v%sr%s" % (tarBallName, major, minor)
         elif patch != None:
             reqstr = "Requires: %s = %s.%s.%s" % (tarBallName, major, minor,
                                                   patch)
@@ -1047,6 +1051,8 @@ Provides: %{package} = %{lhcb_maj_version}.%{lhcb_min_version}.%{lhcb_patch_vers
 Provides: %{fullname} = %{lhcb_maj_version}.%{lhcb_min_version}.%{lhcb_patch_version}
 Provides: %{package}_v%{lhcb_maj_version} = %{lhcb_maj_version}.%{lhcb_min_version}.%{lhcb_patch_version}
 Provides: %{fullname}_v%{lhcb_maj_version} = %{lhcb_maj_version}.%{lhcb_min_version}.%{lhcb_patch_version}
+Provides: %{package}_v%{lhcb_maj_version}r%{lhcb_min_version} = %{lhcb_maj_version}.%{lhcb_min_version}.%{lhcb_patch_version}
+Provides: %{fullname}_v%{lhcb_maj_version}r%{lhcb_min_version} = %{lhcb_maj_version}.%{lhcb_min_version}.%{lhcb_patch_version}
 Requires: %{projectUp}_common
 Requires(post): LBSCRIPTS
 
